==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/streamtuner/st-general-tab.h <==
/*
 * $Id: st-general-tab.h,v 1.10 2004/01/08 13:47:08 jylefort Exp $
 *
 * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_GENERAL_TAB_H
#define _ST_GENERAL_TAB_H

#include <gtk/gtk.h>
#include "st-preferences-tab.h"

#define ST_TYPE_GENERAL_TAB		(st_general_tab_get_type())
#define ST_GENERAL_TAB(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_GENERAL_TAB, STGeneralTab))
#define ST_GENERAL_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_GENERAL_TAB, STGeneralTabClass))
#define ST_IS_GENERAL_TAB(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_GENERAL_TAB))
#define ST_IS_GENERAL_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_GENERAL_TAB))
#define ST_GENERAL_TAB_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_GENERAL_TAB, STGeneralTabClass))

typedef struct
{
  STPreferencesTab		tab;
  
  GtkWidget			*table;

  GtkWidget			*save_automatic_check;
  GtkWidget			*always_refresh_check;
} STGeneralTab;

typedef struct
{
  STPreferencesTabClass		parent_class;
} STGeneralTabClass;

GType		st_general_tab_get_type		(void);
GtkWidget	*st_general_tab_new		(void);

#endif /* _ST_GENERAL_TAB_H */

==> streamtuner-0.12.0.tar.gz: streamtuner-0.12.0/src/streamtuner/st-general-tab.h <==
/*
 * $Id: st-general-tab.h,v 1.12 2004/03/12 15:17:10 jylefort Exp $
 *
 * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_GENERAL_TAB_H
#define _ST_GENERAL_TAB_H

#include <gtk/gtk.h>
#include "st-preferences-tab.h"

#define ST_TYPE_GENERAL_TAB		(st_general_tab_get_type())
#define ST_GENERAL_TAB(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_GENERAL_TAB, STGeneralTab))
#define ST_GENERAL_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_GENERAL_TAB, STGeneralTabClass))
#define ST_IS_GENERAL_TAB(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_GENERAL_TAB))
#define ST_IS_GENERAL_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_GENERAL_TAB))
#define ST_GENERAL_TAB_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_GENERAL_TAB, STGeneralTabClass))

typedef struct _STGeneralTabPrivate STGeneralTabPrivate;

typedef struct
{
  STPreferencesTab		tab;

  STGeneralTabPrivate		*priv;
} STGeneralTab;

typedef struct
{
  STPreferencesTabClass		parent_class;
} STGeneralTabClass;

GType		st_general_tab_get_type		(void);
GtkWidget	*st_general_tab_new		(void);

#endif /* _ST_GENERAL_TAB_H */
